@@ -165,7 +165,11 @@ class Base(Controller):
             (['-id'],{
                 "help": "InstanceId to be passed to ec2 start/stop",
                 "action": "store"
-            })
+            }),
+            (['-r','--region'],{
+                "help": "Which region to use",
+                "action": "store"
+            }),
         ]
     )
     def ec2(self):
@@ -173,9 +177,10 @@ class Base(Controller):
 
         profile = self.app.pargs.profile or 'default'
         filt = self.app.pargs.filter or "live"
+        region = self.app.pargs.region or "eu-west-1"
 
         if self.app.pargs.action=='ls':
-            print(get_ec2('live', profile, filt))
+            print(get_ec2('live', profile, filt, region))
 
         elif self.app.pargs.action=='update':
             print(update_ec2_ssh(profile))
@@ -642,7 +647,7 @@ class Base(Controller):
             raise NotImplemented("Action must be one of {add, ls, dn}")
 
     @ex(
-        help='Execute a Python command across all files in current dir.',
+        help='(WIP/Pre-Alpha) Execute a Python command across all files in current dir.',
         arguments=[
             (['command'],{
                 "help": "what python command to run",
