@@ -57,7 +57,10 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
     ip = f"{get_public_ip()}/32"
 
     profile = profile or 'default'
-    sid = list_security_groups().index[list_security_groups().GroupName==sg_name].tolist()[0]
+    try:
+        sid = list_security_groups().index[list_security_groups().GroupName==sg_name].tolist()[0]
+    except IndexError:
+        raise ValueError(f"Security group called {sg_name} does not exist")
     ec2 = boto3.session.Session(profile_name=profile, region_name='eu-west-1').client('ec2')
 
     target_sg_dict = get_sg(sg_name=sg_name, sid=sid, profile=profile)[0]
@@ -81,7 +84,7 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
         ports = [ int(i.split(':')[0]) for i in items ] 
 
     # TODO: allow for more than just 1 port setting
-    target_ports = [ s['ToPort']==ports[0] for s in sg_res.ip_permissions ]
+    target_ports = [ s['ToPort']==ports[0] for s in sg_res.ip_permissions if 'ToPort' in s.keys()]
     for i in range(len(target_ports)): 
         if target_ports[i]: del sg_res.ip_permissions[i]
 
